@@ -6,6 +6,7 @@ import tabulate
 import time
 from collections import namedtuple
 from queue import Empty
+from random import randint
 
 from .speaker_info import print_speaker_table
 from .utils import (
@@ -57,8 +58,11 @@ def print_list_header(prefix, name):
     print(spacer + underline)
 
 
-def print_tracks(tracks):
-    item_number = 1
+def print_tracks(tracks, single_track=False, track_number=None):
+    if single_track:
+        item_number = track_number
+    else:
+        item_number = 1
     for track in tracks:
         try:
             artist = track.creator
@@ -150,11 +154,27 @@ def no_args_one_output(speaker, action, args, soco_function, use_local_speaker_l
     return True
 
 
-@zero_parameters
+@zero_or_one_parameter
 def list_queue(speaker, action, args, soco_function, use_local_speaker_list):
     queue = speaker.get_queue(max_items=sonos_max_items)
+    if len(queue) == 0:
+        print("Queue is empty")
+        return True
+    if len(args) == 1:
+        try:
+            track_number = int(args[0])
+            if not (0 < track_number <= len(queue)):
+                error_and_exit(
+                    "Track number {} is out of queue range".format(track_number)
+                )
+            queue = [queue[track_number - 1]]
+        except ValueError:
+            parameter_type_error(action, "integer")
     print()
-    print_tracks(queue)
+    if len(args) == 1:
+        print_tracks(queue, single_track=True, track_number=track_number)
+    else:
+        print_tracks(queue)
     print()
     return True
 
@@ -990,16 +1010,38 @@ def tracks_in_album(speaker, action, args, soco_function, use_local_speaker_list
 
 @one_parameter
 def queue_album(speaker, action, args, soco_function, use_local_speaker_list):
-    """Add an album to the queue. If there are multiple matches, only the first
-    will be added.
-    :returns The position in the queue of the first track in the album
+    """Add an album to the queue. If there are multiple matches, a random
+    match will be selected.
+    :returns: The position in the queue of the first track in the album
     """
+    name = args[0]
     albums = speaker.music_library.get_music_library_information(
-        "albums", search_term=args[0], complete_result=True
+        "albums", search_term=name, complete_result=True
     )
-    for album in albums:
+    if len(albums):
+        album = albums[randint(0, len(albums) - 1)]
         print(speaker.add_to_queue(album))
         return True
+    else:
+        error_and_exit("Album '{}' not found".format(name))
+
+
+@one_parameter
+def queue_track(speaker, action, args, soco_function, use_local_speaker_list):
+    """Add a track to the queue. If there are multiple matches, a random match
+    will be selected.
+    :returns: The position in the queue of the track
+    """
+    name = args[0]
+    tracks = speaker.music_library.get_music_library_information(
+        "tracks", search_term=name, complete_result=True
+    )
+    if len(tracks):
+        track = tracks[randint(0, len(tracks) - 1)]
+        print(speaker.add_to_queue(track))
+        return True
+    else:
+        error_and_exit("Track '{}' not found".format(name))
 
 
 @one_or_more_parameters
@@ -1205,4 +1247,6 @@ actions = {
     "artists": SonosFunction(list_artists, ""),
     "queue_album": SonosFunction(queue_album, ""),
     "qa": SonosFunction(queue_album, ""),
+    "queue_track": SonosFunction(queue_track, ""),
+    "qt": SonosFunction(queue_track, ""),
 }
