@@ -1,6 +1,6 @@
 import argparse
 
-from .utils import error_and_exit, configure_logging, version
+from .utils import error_and_exit, configure_logging, version, configure_common_args
 from .speakers import Speakers
 
 
@@ -16,21 +16,7 @@ def main():
         "-p",
         action="store_true",
         default=False,
-        help="Print the discovery results",
-    )
-    parser.add_argument(
-        "--network-discovery-threads",
-        "-t",
-        type=int,
-        default=128,
-        help="Maximum number of threads used for Sonos network discovery",
-    )
-    parser.add_argument(
-        "--network-discovery-timeout",
-        "-n",
-        type=float,
-        default=2.0,
-        help="Network timeout for Sonos device scan (seconds)",
+        help="Print the contents of the current speaker information file, and exit",
     )
     parser.add_argument(
         "--delete-local-speaker-cache",
@@ -39,26 +25,8 @@ def main():
         default=False,
         help="Delete the local speaker cache, if it exists",
     )
-    parser.add_argument(
-        "--show-local-speaker-cache",
-        "-s",
-        action="store_true",
-        default=False,
-        help="Show contents of the local speaker cache",
-    )
-    parser.add_argument(
-        "--version",
-        "-v",
-        action="store_true",
-        default=False,
-        help="Show the soco-cli and SoCo version, and exit.",
-    )
-    parser.add_argument(
-        "--log",
-        type=str,
-        default="NONE",
-        help="Set the logging level: 'NONE' (default) |'CRITICAL' | 'ERROR' | 'WARN'| 'INFO' | 'DEBUG'",
-    )
+    # The rest of the optional args are common
+    configure_common_args(parser)
 
     # Parse the command line
     args = parser.parse_args()
@@ -71,19 +39,20 @@ def main():
 
     speaker_list = Speakers()
 
-    if args.show_local_speaker_cache:
+    if args.print:
         if speaker_list.load():
             speaker_list.print()
             exit(0)
         else:
-            error_and_exit("No cached speaker data")
+            error_and_exit("No current speaker data")
 
     if args.delete_local_speaker_cache:
         try:
-            speaker_list.remove_save_file()
+            file = speaker_list.remove_save_file()
+            print("Removed file: {}".format(file))
             exit(0)
-        except Exception as e:
-            error_and_exit(str(e))
+        except Exception:
+            error_and_exit("No current speaker data file")
 
     # Parameter validation
     if not 1 <= args.network_discovery_threads <= 1024:
@@ -99,17 +68,12 @@ def main():
     speaker_list.network_timeout = args.network_discovery_timeout
 
     try:
-        if args.delete_local_speaker_cache:
-            speaker_list.remove_save_file()
-            exit(0)
         speaker_list.discover()
         speaker_list.save()
+        speaker_list.print()
     except Exception as e:
         error_and_exit(str(e))
 
-    if args.print:
-        speaker_list.print()
-
 
 if __name__ == "__main__":
     main()
